pub enum DaemonError {
Show 22 variants UnsupportedOnOS, Fork, ChDir, OpenDevNull, CloseFp, InvalidUser, InvalidGroup, InvalidUserGroupPair, InvalidCstr, InitGroups, SetUid, SetGid, ChownPid, OpenPid, WritePid, RedirectStream, InvalidUmaskBits, SetSid, GetGrRecord, GetPasswdRecord, SetProcName, InvalidProcName, // some variants omitted
}

Variants

UnsupportedOnOS

This feature is unavailable, or not implemented for your target os

Fork

Unable to fork

ChDir

Failed to chdir

OpenDevNull

Failed to open dev null

CloseFp

Failed to close the file pointer of a stdio stream

InvalidUser

Invalid or nonexistent user

InvalidGroup

Invalid or nonexistent group

InvalidUserGroupPair

Either group or user was specified but no the other

InvalidCstr

The specified cstr is invalid

InitGroups

Failed to execute initgroups

SetUid

Failed to set uid

SetGid

Failed to set gid

ChownPid

Failed to chown the pid file

OpenPid

Failed to create the pid file

WritePid

Failed to write to the pid file

RedirectStream

Failed to redirect the standard streams

InvalidUmaskBits

Umask bits are invalid

SetSid

Failed to set sid

GetGrRecord

Failed to get groups record

GetPasswdRecord

Failed to get passwd record

SetProcName

Failed to set proc name

InvalidProcName