pub struct Group {
pub id: u32,
pub name: String,
}Expand description
Expects: either the group name or a gid if the name is provided it will be resolved to an id
Fields
id: u32name: StringTrait Implementations
impl Eq for Group
Sourceimpl Ord for Group
impl Ord for Group
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for Group
impl PartialOrd for Group
impl StructuralPartialEq for Group